/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlistview.sip"
#include <qlistview.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 612 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 126 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractscrollarea.sip"
#include <qabstractscrollarea.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qscrollbar.sip"
#include <qscrollbar.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 230 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 233 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 236 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 242 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 245 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 248 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 251 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 257 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 260 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 263 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 266 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 272 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 275 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 278 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 286 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 289 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 292 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 295 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 298 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 301 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 304 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 307 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 310 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQListView.cpp"


class sipQListView : public ::QListView
{
public:
    sipQListView(::QWidget*);
    virtual ~sipQListView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setupViewport(::QWidget*) SIP_OVERRIDE;
    void scrollContentsBy(int, int) SIP_OVERRIDE;
    bool viewportEvent(::QEvent*) SIP_OVERRIDE;
    ::QSize viewportSizeHint() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void initStyleOption(::QStyleOptionFrame*) const SIP_OVERRIDE;
    void setModel(::QAbstractItemModel*) SIP_OVERRIDE;
    void setSelectionModel(::QItemSelectionModel*) SIP_OVERRIDE;
    void keyboardSearch(const ::QString&) SIP_OVERRIDE;
    ::QRect visualRect(const ::QModelIndex&) const SIP_OVERRIDE;
    void scrollTo(const ::QModelIndex&, ::QAbstractItemView::ScrollHint) SIP_OVERRIDE;
    ::QModelIndex indexAt(const ::QPoint&) const SIP_OVERRIDE;
    int sizeHintForRow(int) const SIP_OVERRIDE;
    int sizeHintForColumn(int) const SIP_OVERRIDE;
    void reset() SIP_OVERRIDE;
    void setRootIndex(const ::QModelIndex&) SIP_OVERRIDE;
    void selectAll() SIP_OVERRIDE;
    void dataChanged(const ::QModelIndex&, const ::QModelIndex&, const ::QList<int>&) SIP_OVERRIDE;
    void rowsInserted(const ::QModelIndex&, int, int) SIP_OVERRIDE;
    void rowsAboutToBeRemoved(const ::QModelIndex&, int, int) SIP_OVERRIDE;
    void selectionChanged(const ::QItemSelection&, const ::QItemSelection&) SIP_OVERRIDE;
    void currentChanged(const ::QModelIndex&, const ::QModelIndex&) SIP_OVERRIDE;
    void updateEditorData() SIP_OVERRIDE;
    void updateEditorGeometries() SIP_OVERRIDE;
    void updateGeometries() SIP_OVERRIDE;
    void verticalScrollbarAction(int) SIP_OVERRIDE;
    void horizontalScrollbarAction(int) SIP_OVERRIDE;
    void verticalScrollbarValueChanged(int) SIP_OVERRIDE;
    void horizontalScrollbarValueChanged(int) SIP_OVERRIDE;
    void closeEditor(::QWidget*, ::QAbstractItemDelegate::EndEditHint) SIP_OVERRIDE;
    void commitData(::QWidget*) SIP_OVERRIDE;
    void editorDestroyed(::QObject*) SIP_OVERRIDE;
    ::QModelIndex moveCursor(::QAbstractItemView::CursorAction, ::Qt::KeyboardModifiers) SIP_OVERRIDE;
    int horizontalOffset() const SIP_OVERRIDE;
    int verticalOffset() const SIP_OVERRIDE;
    bool isIndexHidden(const ::QModelIndex&) const SIP_OVERRIDE;
    void setSelection(const ::QRect&, ::QItemSelectionModel::SelectionFlags) SIP_OVERRIDE;
    ::QRegion visualRegionForSelection(const ::QItemSelection&) const SIP_OVERRIDE;
    ::QModelIndexList selectedIndexes() const SIP_OVERRIDE;
    bool edit(const ::QModelIndex&, ::QAbstractItemView::EditTrigger, ::QEvent*) SIP_OVERRIDE;
    ::QItemSelectionModel::SelectionFlags selectionCommand(const ::QModelIndex&, const ::QEvent*) const SIP_OVERRIDE;
    void startDrag(::Qt::DropActions) SIP_OVERRIDE;
    ::QAbstractItemDelegate* itemDelegateForIndex(const ::QModelIndex&) const SIP_OVERRIDE;
    void initViewItemOption(::QStyleOptionViewItem*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQListView(const sipQListView &);
    sipQListView &operator = (const sipQListView &);

    char sipPyMethods[89];
};

sipQListView::sipQListView(::QWidget*a0): ::QListView(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQListView::~sipQListView()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQListView::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QListView);

    return ::QListView::metaObject();
}

int sipQListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QListView::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QListView, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQListView::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QListView, _clname, &sipCpp) ? sipCpp : ::QListView::qt_metacast(_clname));
}

void sipQListView::setupViewport(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_setupViewport);

    if (!sipMeth)
    {
        ::QListView::setupViewport(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::scrollContentsBy(int a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_scrollContentsBy);

    if (!sipMeth)
    {
        ::QListView::scrollContentsBy(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int);

    sipVH_QtWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQListView::viewportEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_viewportEvent);

    if (!sipMeth)
        return ::QListView::viewportEvent(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQListView::viewportSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewportSizeHint);

    if (!sipMeth)
        return ::QListView::viewportSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QListView::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainter* sipQListView::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QListView::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQListView::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QListView::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQListView::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QListView::hasHeightForWidth();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQListView::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QListView::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQListView::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QListView::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QListView::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QListView::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QListView::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QListView::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QListView::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QListView::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QListView::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QListView::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QListView::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QListView::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QListView::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QListView::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QListView::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QListView::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QListView::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QListView::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QListView::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QListView::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QListView::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QListView::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QListView::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QListView::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QListView::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QListView::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QListView::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QListView::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQListView::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QListView::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQListView::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QListView::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQListView::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QListView::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QListView::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQListView::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[40]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QListView::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPaintEngine* sipQListView::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QListView::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQListView::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QListView::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQListView::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QListView::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQListView::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QListView::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQListView::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QListView::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[46], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QListView::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QListView::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QListView::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QListView::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::initStyleOption(::QStyleOptionFrame*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[50]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QListView::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionFrame*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::setModel(::QAbstractItemModel*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_setModel);

    if (!sipMeth)
    {
        ::QListView::setModel(a0);
        return;
    }

    extern void sipVH_QtWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractItemModel*);

    sipVH_QtWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::setSelectionModel(::QItemSelectionModel*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_setSelectionModel);

    if (!sipMeth)
    {
        ::QListView::setSelectionModel(a0);
        return;
    }

    extern void sipVH_QtWidgets_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QItemSelectionModel*);

    sipVH_QtWidgets_51(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::keyboardSearch(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[53], &sipPySelf, SIP_NULLPTR, sipName_keyboardSearch);

    if (!sipMeth)
    {
        ::QListView::keyboardSearch(a0);
        return;
    }

    extern void sipVH_QtWidgets_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtWidgets_52(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRect sipQListView::visualRect(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[54]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_visualRect);

    if (!sipMeth)
        return ::QListView::visualRect(a0);

    extern ::QRect sipVH_QtWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::scrollTo(const ::QModelIndex& a0, ::QAbstractItemView::ScrollHint a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_scrollTo);

    if (!sipMeth)
    {
        ::QListView::scrollTo(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QAbstractItemView::ScrollHint);

    sipVH_QtWidgets_54(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QModelIndex sipQListView::indexAt(const ::QPoint& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[56]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_indexAt);

    if (!sipMeth)
        return ::QListView::indexAt(a0);

    extern ::QModelIndex sipVH_QtWidgets_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPoint&);

    return sipVH_QtWidgets_55(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQListView::sizeHintForRow(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[57]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHintForRow);

    if (!sipMeth)
        return ::QListView::sizeHintForRow(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQListView::sizeHintForColumn(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[58]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHintForColumn);

    if (!sipMeth)
        return ::QListView::sizeHintForColumn(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[59], &sipPySelf, SIP_NULLPTR, sipName_reset);

    if (!sipMeth)
    {
        ::QListView::reset();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::setRootIndex(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[60], &sipPySelf, SIP_NULLPTR, sipName_setRootIndex);

    if (!sipMeth)
    {
        ::QListView::setRootIndex(a0);
        return;
    }

    extern void sipVH_QtWidgets_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtWidgets_56(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::selectAll()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[61], &sipPySelf, SIP_NULLPTR, sipName_selectAll);

    if (!sipMeth)
    {
        ::QListView::selectAll();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::dataChanged(const ::QModelIndex& a0, const ::QModelIndex& a1, const ::QList<int>& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[62], &sipPySelf, SIP_NULLPTR, sipName_dataChanged);

    if (!sipMeth)
    {
        ::QListView::dataChanged(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QModelIndex&, const ::QList<int>&);

    sipVH_QtWidgets_57(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQListView::rowsInserted(const ::QModelIndex& a0, int a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[63], &sipPySelf, SIP_NULLPTR, sipName_rowsInserted);

    if (!sipMeth)
    {
        ::QListView::rowsInserted(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int);

    sipVH_QtWidgets_58(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQListView::rowsAboutToBeRemoved(const ::QModelIndex& a0, int a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[64], &sipPySelf, SIP_NULLPTR, sipName_rowsAboutToBeRemoved);

    if (!sipMeth)
    {
        ::QListView::rowsAboutToBeRemoved(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int);

    sipVH_QtWidgets_58(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQListView::selectionChanged(const ::QItemSelection& a0, const ::QItemSelection& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[65], &sipPySelf, SIP_NULLPTR, sipName_selectionChanged);

    if (!sipMeth)
    {
        ::QListView::selectionChanged(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QItemSelection&, const ::QItemSelection&);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQListView::currentChanged(const ::QModelIndex& a0, const ::QModelIndex& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[66], &sipPySelf, SIP_NULLPTR, sipName_currentChanged);

    if (!sipMeth)
    {
        ::QListView::currentChanged(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QModelIndex&);

    sipVH_QtWidgets_60(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQListView::updateEditorData()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[67], &sipPySelf, SIP_NULLPTR, sipName_updateEditorData);

    if (!sipMeth)
    {
        ::QListView::updateEditorData();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::updateEditorGeometries()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[68], &sipPySelf, SIP_NULLPTR, sipName_updateEditorGeometries);

    if (!sipMeth)
    {
        ::QListView::updateEditorGeometries();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::updateGeometries()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[69], &sipPySelf, SIP_NULLPTR, sipName_updateGeometries);

    if (!sipMeth)
    {
        ::QListView::updateGeometries();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQListView::verticalScrollbarAction(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[70], &sipPySelf, SIP_NULLPTR, sipName_verticalScrollbarAction);

    if (!sipMeth)
    {
        ::QListView::verticalScrollbarAction(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::horizontalScrollbarAction(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[71], &sipPySelf, SIP_NULLPTR, sipName_horizontalScrollbarAction);

    if (!sipMeth)
    {
        ::QListView::horizontalScrollbarAction(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::verticalScrollbarValueChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[72], &sipPySelf, SIP_NULLPTR, sipName_verticalScrollbarValueChanged);

    if (!sipMeth)
    {
        ::QListView::verticalScrollbarValueChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::horizontalScrollbarValueChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[73], &sipPySelf, SIP_NULLPTR, sipName_horizontalScrollbarValueChanged);

    if (!sipMeth)
    {
        ::QListView::horizontalScrollbarValueChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::closeEditor(::QWidget*a0, ::QAbstractItemDelegate::EndEditHint a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[74], &sipPySelf, SIP_NULLPTR, sipName_closeEditor);

    if (!sipMeth)
    {
        ::QListView::closeEditor(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, ::QAbstractItemDelegate::EndEditHint);

    sipVH_QtWidgets_62(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQListView::commitData(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[75], &sipPySelf, SIP_NULLPTR, sipName_commitData);

    if (!sipMeth)
    {
        ::QListView::commitData(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::editorDestroyed(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[76], &sipPySelf, SIP_NULLPTR, sipName_editorDestroyed);

    if (!sipMeth)
    {
        ::QListView::editorDestroyed(a0);
        return;
    }

    extern void sipVH_QtWidgets_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    sipVH_QtWidgets_63(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQListView::moveCursor(::QAbstractItemView::CursorAction a0, ::Qt::KeyboardModifiers a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[77], &sipPySelf, SIP_NULLPTR, sipName_moveCursor);

    if (!sipMeth)
        return ::QListView::moveCursor(a0, a1);

    extern ::QModelIndex sipVH_QtWidgets_64(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractItemView::CursorAction, ::Qt::KeyboardModifiers);

    return sipVH_QtWidgets_64(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

int sipQListView::horizontalOffset() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[78]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_horizontalOffset);

    if (!sipMeth)
        return ::QListView::horizontalOffset();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQListView::verticalOffset() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[79]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_verticalOffset);

    if (!sipMeth)
        return ::QListView::verticalOffset();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQListView::isIndexHidden(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[80]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isIndexHidden);

    if (!sipMeth)
        return ::QListView::isIndexHidden(a0);

    extern bool sipVH_QtWidgets_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_65(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::setSelection(const ::QRect& a0, ::QItemSelectionModel::SelectionFlags a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[81], &sipPySelf, SIP_NULLPTR, sipName_setSelection);

    if (!sipMeth)
    {
        ::QListView::setSelection(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRect&, ::QItemSelectionModel::SelectionFlags);

    sipVH_QtWidgets_66(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QRegion sipQListView::visualRegionForSelection(const ::QItemSelection& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[82]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_visualRegionForSelection);

    if (!sipMeth)
        return ::QListView::visualRegionForSelection(a0);

    extern ::QRegion sipVH_QtWidgets_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QItemSelection&);

    return sipVH_QtWidgets_67(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QModelIndexList sipQListView::selectedIndexes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[83]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectedIndexes);

    if (!sipMeth)
        return ::QListView::selectedIndexes();

    extern ::QModelIndexList sipVH_QtWidgets_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_68(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQListView::edit(const ::QModelIndex& a0, ::QAbstractItemView::EditTrigger a1, ::QEvent*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[84], &sipPySelf, SIP_NULLPTR, sipName_edit);

    if (!sipMeth)
        return ::QListView::edit(a0, a1, a2);

    extern bool sipVH_QtWidgets_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QAbstractItemView::EditTrigger, ::QEvent*);

    return sipVH_QtWidgets_69(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QItemSelectionModel::SelectionFlags sipQListView::selectionCommand(const ::QModelIndex& a0, const ::QEvent*a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[85]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectionCommand);

    if (!sipMeth)
        return ::QListView::selectionCommand(a0, a1);

    extern ::QItemSelectionModel::SelectionFlags sipVH_QtWidgets_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QEvent*);

    return sipVH_QtWidgets_70(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQListView::startDrag(::Qt::DropActions a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[86], &sipPySelf, SIP_NULLPTR, sipName_startDrag);

    if (!sipMeth)
    {
        ::QListView::startDrag(a0);
        return;
    }

    extern void sipVH_QtWidgets_71(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::DropActions);

    sipVH_QtWidgets_71(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QAbstractItemDelegate* sipQListView::itemDelegateForIndex(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[87]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemDelegateForIndex);

    if (!sipMeth)
        return ::QListView::itemDelegateForIndex(a0);

    extern ::QAbstractItemDelegate* sipVH_QtWidgets_72(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_72(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQListView::initViewItemOption(::QStyleOptionViewItem*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[88]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initViewItemOption);

    if (!sipMeth)
    {
        ::QListView::initViewItemOption(a0);
        return;
    }

    extern void sipVH_QtWidgets_73(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionViewItem*);

    sipVH_QtWidgets_73(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QListView_setMovement, "setMovement(self, movement: QListView.Movement)");

extern "C" {static PyObject *meth_QListView_setMovement(PyObject *, PyObject *);}
static PyObject *meth_QListView_setMovement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QListView::Movement a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QListView, &sipCpp, sipType_QListView_Movement, &a0))
        {
            sipCpp->setMovement(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setMovement, doc_QListView_setMovement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_movement, "movement(self) -> QListView.Movement");

extern "C" {static PyObject *meth_QListView_movement(PyObject *, PyObject *);}
static PyObject *meth_QListView_movement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QListView::Movement sipRes;

            sipRes = sipCpp->movement();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QListView_Movement);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_movement, doc_QListView_movement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setFlow, "setFlow(self, flow: QListView.Flow)");

extern "C" {static PyObject *meth_QListView_setFlow(PyObject *, PyObject *);}
static PyObject *meth_QListView_setFlow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QListView::Flow a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QListView, &sipCpp, sipType_QListView_Flow, &a0))
        {
            sipCpp->setFlow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setFlow, doc_QListView_setFlow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_flow, "flow(self) -> QListView.Flow");

extern "C" {static PyObject *meth_QListView_flow(PyObject *, PyObject *);}
static PyObject *meth_QListView_flow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QListView::Flow sipRes;

            sipRes = sipCpp->flow();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QListView_Flow);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_flow, doc_QListView_flow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setWrapping, "setWrapping(self, enable: bool)");

extern "C" {static PyObject *meth_QListView_setWrapping(PyObject *, PyObject *);}
static PyObject *meth_QListView_setWrapping(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setWrapping(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setWrapping, doc_QListView_setWrapping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_isWrapping, "isWrapping(self) -> bool");

extern "C" {static PyObject *meth_QListView_isWrapping(PyObject *, PyObject *);}
static PyObject *meth_QListView_isWrapping(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isWrapping();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_isWrapping, doc_QListView_isWrapping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setResizeMode, "setResizeMode(self, mode: QListView.ResizeMode)");

extern "C" {static PyObject *meth_QListView_setResizeMode(PyObject *, PyObject *);}
static PyObject *meth_QListView_setResizeMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QListView::ResizeMode a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QListView, &sipCpp, sipType_QListView_ResizeMode, &a0))
        {
            sipCpp->setResizeMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setResizeMode, doc_QListView_setResizeMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_resizeMode, "resizeMode(self) -> QListView.ResizeMode");

extern "C" {static PyObject *meth_QListView_resizeMode(PyObject *, PyObject *);}
static PyObject *meth_QListView_resizeMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QListView::ResizeMode sipRes;

            sipRes = sipCpp->resizeMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QListView_ResizeMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_resizeMode, doc_QListView_resizeMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setLayoutMode, "setLayoutMode(self, mode: QListView.LayoutMode)");

extern "C" {static PyObject *meth_QListView_setLayoutMode(PyObject *, PyObject *);}
static PyObject *meth_QListView_setLayoutMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QListView::LayoutMode a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QListView, &sipCpp, sipType_QListView_LayoutMode, &a0))
        {
            sipCpp->setLayoutMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setLayoutMode, doc_QListView_setLayoutMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_layoutMode, "layoutMode(self) -> QListView.LayoutMode");

extern "C" {static PyObject *meth_QListView_layoutMode(PyObject *, PyObject *);}
static PyObject *meth_QListView_layoutMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QListView::LayoutMode sipRes;

            sipRes = sipCpp->layoutMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QListView_LayoutMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_layoutMode, doc_QListView_layoutMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setSpacing, "setSpacing(self, space: int)");

extern "C" {static PyObject *meth_QListView_setSpacing(PyObject *, PyObject *);}
static PyObject *meth_QListView_setSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setSpacing(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setSpacing, doc_QListView_setSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_spacing, "spacing(self) -> int");

extern "C" {static PyObject *meth_QListView_spacing(PyObject *, PyObject *);}
static PyObject *meth_QListView_spacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->spacing();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_spacing, doc_QListView_spacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setGridSize, "setGridSize(self, size: QSize)");

extern "C" {static PyObject *meth_QListView_setGridSize(PyObject *, PyObject *);}
static PyObject *meth_QListView_setGridSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setGridSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setGridSize, doc_QListView_setGridSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_gridSize, "gridSize(self) -> QSize");

extern "C" {static PyObject *meth_QListView_gridSize(PyObject *, PyObject *);}
static PyObject *meth_QListView_gridSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->gridSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_gridSize, doc_QListView_gridSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setViewMode, "setViewMode(self, mode: QListView.ViewMode)");

extern "C" {static PyObject *meth_QListView_setViewMode(PyObject *, PyObject *);}
static PyObject *meth_QListView_setViewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QListView::ViewMode a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QListView, &sipCpp, sipType_QListView_ViewMode, &a0))
        {
            sipCpp->setViewMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setViewMode, doc_QListView_setViewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_viewMode, "viewMode(self) -> QListView.ViewMode");

extern "C" {static PyObject *meth_QListView_viewMode(PyObject *, PyObject *);}
static PyObject *meth_QListView_viewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QListView::ViewMode sipRes;

            sipRes = sipCpp->viewMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QListView_ViewMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_viewMode, doc_QListView_viewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_clearPropertyFlags, "clearPropertyFlags(self)");

extern "C" {static PyObject *meth_QListView_clearPropertyFlags(PyObject *, PyObject *);}
static PyObject *meth_QListView_clearPropertyFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            sipCpp->clearPropertyFlags();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_clearPropertyFlags, doc_QListView_clearPropertyFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_isRowHidden, "isRowHidden(self, row: int) -> bool");

extern "C" {static PyObject *meth_QListView_isRowHidden(PyObject *, PyObject *);}
static PyObject *meth_QListView_isRowHidden(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isRowHidden(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_isRowHidden, doc_QListView_isRowHidden);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setRowHidden, "setRowHidden(self, row: int, hide: bool)");

extern "C" {static PyObject *meth_QListView_setRowHidden(PyObject *, PyObject *);}
static PyObject *meth_QListView_setRowHidden(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        bool a1;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bib", &sipSelf, sipType_QListView, &sipCpp, &a0, &a1))
        {
            sipCpp->setRowHidden(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setRowHidden, doc_QListView_setRowHidden);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setModelColumn, "setModelColumn(self, column: int)");

extern "C" {static PyObject *meth_QListView_setModelColumn(PyObject *, PyObject *);}
static PyObject *meth_QListView_setModelColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setModelColumn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setModelColumn, doc_QListView_setModelColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_modelColumn, "modelColumn(self) -> int");

extern "C" {static PyObject *meth_QListView_modelColumn(PyObject *, PyObject *);}
static PyObject *meth_QListView_modelColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->modelColumn();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_modelColumn, doc_QListView_modelColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setUniformItemSizes, "setUniformItemSizes(self, enable: bool)");

extern "C" {static PyObject *meth_QListView_setUniformItemSizes(PyObject *, PyObject *);}
static PyObject *meth_QListView_setUniformItemSizes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setUniformItemSizes(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setUniformItemSizes, doc_QListView_setUniformItemSizes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_uniformItemSizes, "uniformItemSizes(self) -> bool");

extern "C" {static PyObject *meth_QListView_uniformItemSizes(PyObject *, PyObject *);}
static PyObject *meth_QListView_uniformItemSizes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->uniformItemSizes();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_uniformItemSizes, doc_QListView_uniformItemSizes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_visualRect, "visualRect(self, index: QModelIndex) -> QRect");

extern "C" {static PyObject *meth_QListView_visualRect(PyObject *, PyObject *);}
static PyObject *meth_QListView_visualRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect((sipSelfWasArg ? sipCpp->::QListView::visualRect(*a0) : sipCpp->visualRect(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_visualRect, doc_QListView_visualRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_scrollTo, "scrollTo(self, index: QModelIndex, hint: QAbstractItemView.ScrollHint = QAbstractItemView.EnsureVisible)");

extern "C" {static PyObject *meth_QListView_scrollTo(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QListView_scrollTo(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        ::QAbstractItemView::ScrollHint a1 = QAbstractItemView::EnsureVisible;
        ::QListView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_hint,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|E", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0, sipType_QAbstractItemView_ScrollHint, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QListView::scrollTo(*a0, a1) : sipCpp->scrollTo(*a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_scrollTo, doc_QListView_scrollTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_indexAt, "indexAt(self, p: QPoint) -> QModelIndex");

extern "C" {static PyObject *meth_QListView_indexAt(PyObject *, PyObject *);}
static PyObject *meth_QListView_indexAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPoint* a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QPoint, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QListView::indexAt(*a0) : sipCpp->indexAt(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_indexAt, doc_QListView_indexAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_reset, "reset(self)");

extern "C" {static PyObject *meth_QListView_reset(PyObject *, PyObject *);}
static PyObject *meth_QListView_reset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QListView::reset() : sipCpp->reset());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_reset, doc_QListView_reset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setRootIndex, "setRootIndex(self, index: QModelIndex)");

extern "C" {static PyObject *meth_QListView_setRootIndex(PyObject *, PyObject *);}
static PyObject *meth_QListView_setRootIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::setRootIndex(*a0) : sipCpp->setRootIndex(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setRootIndex, doc_QListView_setRootIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_scrollContentsBy, "scrollContentsBy(self, dx: int, dy: int)");

extern "C" {static PyObject *meth_QListView_scrollContentsBy(PyObject *, PyObject *);}
static PyObject *meth_QListView_scrollContentsBy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pii", &sipSelf, sipType_QListView, &sipCpp, &a0, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QListView::scrollContentsBy(a0, a1) : sipCpp->scrollContentsBy(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_scrollContentsBy, doc_QListView_scrollContentsBy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_dataChanged, "dataChanged(self, topLeft: QModelIndex, bottomRight: QModelIndex, roles: Iterable[int] = [])");

extern "C" {static PyObject *meth_QListView_dataChanged(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QListView_dataChanged(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QModelIndex* a1;
        const ::QList<int>& a2def = QList<int>();
        const ::QList<int>* a2 = &a2def;
        int a2State = 0;
        ::QListView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_roles,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "pJ9J9|J1", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0, sipType_QModelIndex, &a1, sipType_QList_1800, &a2, &a2State))
        {
            (sipSelfWasArg ? sipCpp->::QListView::dataChanged(*a0, *a1, *a2) : sipCpp->dataChanged(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QList<int> *>(a2), sipType_QList_1800, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_dataChanged, doc_QListView_dataChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_rowsInserted, "rowsInserted(self, parent: QModelIndex, start: int, end: int)");

extern "C" {static PyObject *meth_QListView_rowsInserted(PyObject *, PyObject *);}
static PyObject *meth_QListView_rowsInserted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1;
        int a2;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9ii", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0, &a1, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QListView::rowsInserted(*a0, a1, a2) : sipCpp->rowsInserted(*a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_rowsInserted, doc_QListView_rowsInserted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_rowsAboutToBeRemoved, "rowsAboutToBeRemoved(self, parent: QModelIndex, start: int, end: int)");

extern "C" {static PyObject *meth_QListView_rowsAboutToBeRemoved(PyObject *, PyObject *);}
static PyObject *meth_QListView_rowsAboutToBeRemoved(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1;
        int a2;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9ii", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0, &a1, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QListView::rowsAboutToBeRemoved(*a0, a1, a2) : sipCpp->rowsAboutToBeRemoved(*a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_rowsAboutToBeRemoved, doc_QListView_rowsAboutToBeRemoved);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_event, "event(self, e: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QListView_event(PyObject *, PyObject *);}
static PyObject *meth_QListView_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QListView::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_event, doc_QListView_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_mouseMoveEvent, "mouseMoveEvent(self, e: QMouseEvent|None)");

extern "C" {static PyObject *meth_QListView_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_mouseMoveEvent, doc_QListView_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_mouseReleaseEvent, "mouseReleaseEvent(self, e: QMouseEvent|None)");

extern "C" {static PyObject *meth_QListView_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_mouseReleaseEvent, doc_QListView_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_timerEvent, "timerEvent(self, e: QTimerEvent|None)");

extern "C" {static PyObject *meth_QListView_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTimerEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_timerEvent, doc_QListView_timerEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_resizeEvent, "resizeEvent(self, e: QResizeEvent|None)");

extern "C" {static PyObject *meth_QListView_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_resizeEvent, doc_QListView_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_dragMoveEvent, "dragMoveEvent(self, e: QDragMoveEvent|None)");

extern "C" {static PyObject *meth_QListView_dragMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_dragMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragMoveEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QDragMoveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::dragMoveEvent(a0) : sipCpp->dragMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_dragMoveEvent, doc_QListView_dragMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_dragLeaveEvent, "dragLeaveEvent(self, e: QDragLeaveEvent|None)");

extern "C" {static PyObject *meth_QListView_dragLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_dragLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragLeaveEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QDragLeaveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::dragLeaveEvent(a0) : sipCpp->dragLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_dragLeaveEvent, doc_QListView_dragLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_dropEvent, "dropEvent(self, e: QDropEvent|None)");

extern "C" {static PyObject *meth_QListView_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDropEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_dropEvent, doc_QListView_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_wheelEvent, "wheelEvent(self, e: QWheelEvent|None)");

extern "C" {static PyObject *meth_QListView_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_wheelEvent, doc_QListView_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_startDrag, "startDrag(self, supportedActions: Qt.DropAction)");

extern "C" {static PyObject *meth_QListView_startDrag(PyObject *, PyObject *);}
static PyObject *meth_QListView_startDrag(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::DropActions* a0;
        int a0State = 0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QListView, &sipCpp, sipType_QFlags_0100Qt_DropAction, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QListView::startDrag(*a0) : sipCpp->startDrag(*a0));
            sipReleaseType(a0, sipType_QFlags_0100Qt_DropAction, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_startDrag, doc_QListView_startDrag);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_paintEvent, "paintEvent(self, e: QPaintEvent|None)");

extern "C" {static PyObject *meth_QListView_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QListView_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_paintEvent, doc_QListView_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_horizontalOffset, "horizontalOffset(self) -> int");

extern "C" {static PyObject *meth_QListView_horizontalOffset(PyObject *, PyObject *);}
static PyObject *meth_QListView_horizontalOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QListView, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QListView::horizontalOffset() : sipCpp->horizontalOffset());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_horizontalOffset, doc_QListView_horizontalOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_verticalOffset, "verticalOffset(self) -> int");

extern "C" {static PyObject *meth_QListView_verticalOffset(PyObject *, PyObject *);}
static PyObject *meth_QListView_verticalOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QListView, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QListView::verticalOffset() : sipCpp->verticalOffset());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_verticalOffset, doc_QListView_verticalOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_moveCursor, "moveCursor(self, cursorAction: QAbstractItemView.CursorAction, modifiers: Qt.KeyboardModifier) -> QModelIndex");

extern "C" {static PyObject *meth_QListView_moveCursor(PyObject *, PyObject *);}
static PyObject *meth_QListView_moveCursor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractItemView::CursorAction a0;
        ::Qt::KeyboardModifiers* a1;
        int a1State = 0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QListView, &sipCpp, sipType_QAbstractItemView_CursorAction, &a0, sipType_QFlags_0100Qt_KeyboardModifier, &a1, &a1State))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QListView::moveCursor(a0, *a1) : sipCpp->moveCursor(a0, *a1)));
            sipReleaseType(a1, sipType_QFlags_0100Qt_KeyboardModifier, a1State);

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_moveCursor, doc_QListView_moveCursor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_rectForIndex, "rectForIndex(self, index: QModelIndex) -> QRect");

extern "C" {static PyObject *meth_QListView_rectForIndex(PyObject *, PyObject *);}
static PyObject *meth_QListView_rectForIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->rectForIndex(*a0));

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_rectForIndex, doc_QListView_rectForIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setPositionForIndex, "setPositionForIndex(self, position: QPoint, index: QModelIndex)");

extern "C" {static PyObject *meth_QListView_setPositionForIndex(PyObject *, PyObject *);}
static PyObject *meth_QListView_setPositionForIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        const ::QModelIndex* a1;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9J9", &sipSelf, sipType_QListView, &sipCpp, sipType_QPoint, &a0, sipType_QModelIndex, &a1))
        {
            sipCpp->setPositionForIndex(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setPositionForIndex, doc_QListView_setPositionForIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setSelection, "setSelection(self, rect: QRect, command: QItemSelectionModel.SelectionFlag)");

extern "C" {static PyObject *meth_QListView_setSelection(PyObject *, PyObject *);}
static PyObject *meth_QListView_setSelection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRect* a0;
        ::QItemSelectionModel::SelectionFlags* a1;
        int a1State = 0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9J1", &sipSelf, sipType_QListView, &sipCpp, sipType_QRect, &a0, sipType_QFlags_0100QItemSelectionModel_SelectionFlag, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QListView::setSelection(*a0, *a1) : sipCpp->setSelection(*a0, *a1));
            sipReleaseType(a1, sipType_QFlags_0100QItemSelectionModel_SelectionFlag, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setSelection, doc_QListView_setSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_visualRegionForSelection, "visualRegionForSelection(self, selection: QItemSelection) -> QRegion");

extern "C" {static PyObject *meth_QListView_visualRegionForSelection(PyObject *, PyObject *);}
static PyObject *meth_QListView_visualRegionForSelection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QItemSelection* a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QItemSelection, &a0))
        {
            ::QRegion*sipRes;

            sipRes = new ::QRegion((sipSelfWasArg ? sipCpp->::QListView::visualRegionForSelection(*a0) : sipCpp->visualRegionForSelection(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QRegion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_visualRegionForSelection, doc_QListView_visualRegionForSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_selectedIndexes, "selectedIndexes(self) -> list[QModelIndex]");

extern "C" {static PyObject *meth_QListView_selectedIndexes(PyObject *, PyObject *);}
static PyObject *meth_QListView_selectedIndexes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QModelIndexList*sipRes;

            sipRes = new ::QModelIndexList((sipSelfWasArg ? sipCpp->::QListView::selectedIndexes() : sipCpp->selectedIndexes()));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_selectedIndexes, doc_QListView_selectedIndexes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_updateGeometries, "updateGeometries(self)");

extern "C" {static PyObject *meth_QListView_updateGeometries(PyObject *, PyObject *);}
static PyObject *meth_QListView_updateGeometries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QListView, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QListView::updateGeometries() : sipCpp->updateGeometries());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_updateGeometries, doc_QListView_updateGeometries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_isIndexHidden, "isIndexHidden(self, index: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QListView_isIndexHidden(PyObject *, PyObject *);}
static PyObject *meth_QListView_isIndexHidden(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QListView::isIndexHidden(*a0) : sipCpp->isIndexHidden(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_isIndexHidden, doc_QListView_isIndexHidden);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_viewportSizeHint, "viewportSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QListView_viewportSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QListView_viewportSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QListView::viewportSizeHint() : sipCpp->viewportSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_viewportSizeHint, doc_QListView_viewportSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setBatchSize, "setBatchSize(self, batchSize: int)");

extern "C" {static PyObject *meth_QListView_setBatchSize(PyObject *, PyObject *);}
static PyObject *meth_QListView_setBatchSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setBatchSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setBatchSize, doc_QListView_setBatchSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_batchSize, "batchSize(self) -> int");

extern "C" {static PyObject *meth_QListView_batchSize(PyObject *, PyObject *);}
static PyObject *meth_QListView_batchSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->batchSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_batchSize, doc_QListView_batchSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setWordWrap, "setWordWrap(self, on: bool)");

extern "C" {static PyObject *meth_QListView_setWordWrap(PyObject *, PyObject *);}
static PyObject *meth_QListView_setWordWrap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setWordWrap(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setWordWrap, doc_QListView_setWordWrap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_wordWrap, "wordWrap(self) -> bool");

extern "C" {static PyObject *meth_QListView_wordWrap(PyObject *, PyObject *);}
static PyObject *meth_QListView_wordWrap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->wordWrap();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_wordWrap, doc_QListView_wordWrap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setSelectionRectVisible, "setSelectionRectVisible(self, show: bool)");

extern "C" {static PyObject *meth_QListView_setSelectionRectVisible(PyObject *, PyObject *);}
static PyObject *meth_QListView_setSelectionRectVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QListView, &sipCpp, &a0))
        {
            sipCpp->setSelectionRectVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setSelectionRectVisible, doc_QListView_setSelectionRectVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_isSelectionRectVisible, "isSelectionRectVisible(self) -> bool");

extern "C" {static PyObject *meth_QListView_isSelectionRectVisible(PyObject *, PyObject *);}
static PyObject *meth_QListView_isSelectionRectVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSelectionRectVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_isSelectionRectVisible, doc_QListView_isSelectionRectVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_selectionChanged, "selectionChanged(self, selected: QItemSelection, deselected: QItemSelection)");

extern "C" {static PyObject *meth_QListView_selectionChanged(PyObject *, PyObject *);}
static PyObject *meth_QListView_selectionChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QItemSelection* a0;
        const ::QItemSelection* a1;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9J9", &sipSelf, sipType_QListView, &sipCpp, sipType_QItemSelection, &a0, sipType_QItemSelection, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QListView::selectionChanged(*a0, *a1) : sipCpp->selectionChanged(*a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_selectionChanged, doc_QListView_selectionChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_currentChanged, "currentChanged(self, current: QModelIndex, previous: QModelIndex)");

extern "C" {static PyObject *meth_QListView_currentChanged(PyObject *, PyObject *);}
static PyObject *meth_QListView_currentChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QModelIndex* a1;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9J9", &sipSelf, sipType_QListView, &sipCpp, sipType_QModelIndex, &a0, sipType_QModelIndex, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QListView::currentChanged(*a0, *a1) : sipCpp->currentChanged(*a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_currentChanged, doc_QListView_currentChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_initViewItemOption, "initViewItemOption(self, option: QStyleOptionViewItem|None)");

extern "C" {static PyObject *meth_QListView_initViewItemOption(PyObject *, PyObject *);}
static PyObject *meth_QListView_initViewItemOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QListView)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QStyleOptionViewItem* a0;
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QListView, &sipCpp, sipType_QStyleOptionViewItem, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QListView::initViewItemOption(a0) : sipCpp->initViewItemOption(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_initViewItemOption, doc_QListView_initViewItemOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_setItemAlignment, "setItemAlignment(self, alignment: Qt.AlignmentFlag)");

extern "C" {static PyObject *meth_QListView_setItemAlignment(PyObject *, PyObject *);}
static PyObject *meth_QListView_setItemAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Alignment* a0;
        int a0State = 0;
        ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QListView, &sipCpp, sipType_QFlags_0100Qt_AlignmentFlag, &a0, &a0State))
        {
            sipCpp->setItemAlignment(*a0);
            sipReleaseType(a0, sipType_QFlags_0100Qt_AlignmentFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_setItemAlignment, doc_QListView_setItemAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QListView_itemAlignment, "itemAlignment(self) -> Qt.AlignmentFlag");

extern "C" {static PyObject *meth_QListView_itemAlignment(PyObject *, PyObject *);}
static PyObject *meth_QListView_itemAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QListView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QListView, &sipCpp))
        {
            ::Qt::Alignment*sipRes;

            sipRes = new ::Qt::Alignment(sipCpp->itemAlignment());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_AlignmentFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QListView, sipName_itemAlignment, doc_QListView_itemAlignment);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QListView(void *, const sipTypeDef *);}
static void *cast_QListView(void *sipCppV, const sipTypeDef *targetType)
{
    ::QListView *sipCpp = reinterpret_cast< ::QListView *>(sipCppV);

    if (targetType == sipType_QListView)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractItemView)->ctd_cast(static_cast< ::QAbstractItemView *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QListView(void *, int);}
static void release_QListView(void *sipCppV, int)
{
    ::QListView *sipCpp = reinterpret_cast< ::QListView *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QListView(Py_ssize_t);}
static void *array_QListView(Py_ssize_t sipNrElem)
{
    return new ::QListView[sipNrElem];
}


extern "C" {static void array_delete_QListView(void *);}
static void array_delete_QListView(void *sipCpp)
{
    delete[] reinterpret_cast< ::QListView *>(sipCpp);
}


extern "C" {static void dealloc_QListView(sipSimpleWrapper *);}
static void dealloc_QListView(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQListView *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QListView(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QListView(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QListView(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQListView *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQListView(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QListView[] = {{4, 255, 1}};


static PyMethodDef methods_QListView[] = {
    {sipName_batchSize, meth_QListView_batchSize, METH_VARARGS, doc_QListView_batchSize},
    {sipName_clearPropertyFlags, meth_QListView_clearPropertyFlags, METH_VARARGS, doc_QListView_clearPropertyFlags},
    {sipName_currentChanged, meth_QListView_currentChanged, METH_VARARGS, doc_QListView_currentChanged},
    {sipName_dataChanged, SIP_MLMETH_CAST(meth_QListView_dataChanged), METH_VARARGS|METH_KEYWORDS, doc_QListView_dataChanged},
    {sipName_dragLeaveEvent, meth_QListView_dragLeaveEvent, METH_VARARGS, doc_QListView_dragLeaveEvent},
    {sipName_dragMoveEvent, meth_QListView_dragMoveEvent, METH_VARARGS, doc_QListView_dragMoveEvent},
    {sipName_dropEvent, meth_QListView_dropEvent, METH_VARARGS, doc_QListView_dropEvent},
    {sipName_event, meth_QListView_event, METH_VARARGS, doc_QListView_event},
    {sipName_flow, meth_QListView_flow, METH_VARARGS, doc_QListView_flow},
    {sipName_gridSize, meth_QListView_gridSize, METH_VARARGS, doc_QListView_gridSize},
    {sipName_horizontalOffset, meth_QListView_horizontalOffset, METH_VARARGS, doc_QListView_horizontalOffset},
    {sipName_indexAt, meth_QListView_indexAt, METH_VARARGS, doc_QListView_indexAt},
    {sipName_initViewItemOption, meth_QListView_initViewItemOption, METH_VARARGS, doc_QListView_initViewItemOption},
    {sipName_isIndexHidden, meth_QListView_isIndexHidden, METH_VARARGS, doc_QListView_isIndexHidden},
    {sipName_isRowHidden, meth_QListView_isRowHidden, METH_VARARGS, doc_QListView_isRowHidden},
    {sipName_isSelectionRectVisible, meth_QListView_isSelectionRectVisible, METH_VARARGS, doc_QListView_isSelectionRectVisible},
    {sipName_isWrapping, meth_QListView_isWrapping, METH_VARARGS, doc_QListView_isWrapping},
    {sipName_itemAlignment, meth_QListView_itemAlignment, METH_VARARGS, doc_QListView_itemAlignment},
    {sipName_layoutMode, meth_QListView_layoutMode, METH_VARARGS, doc_QListView_layoutMode},
    {sipName_modelColumn, meth_QListView_modelColumn, METH_VARARGS, doc_QListView_modelColumn},
    {sipName_mouseMoveEvent, meth_QListView_mouseMoveEvent, METH_VARARGS, doc_QListView_mouseMoveEvent},
    {sipName_mouseReleaseEvent, meth_QListView_mouseReleaseEvent, METH_VARARGS, doc_QListView_mouseReleaseEvent},
    {sipName_moveCursor, meth_QListView_moveCursor, METH_VARARGS, doc_QListView_moveCursor},
    {sipName_movement, meth_QListView_movement, METH_VARARGS, doc_QListView_movement},
    {sipName_paintEvent, meth_QListView_paintEvent, METH_VARARGS, doc_QListView_paintEvent},
    {sipName_rectForIndex, meth_QListView_rectForIndex, METH_VARARGS, doc_QListView_rectForIndex},
    {sipName_reset, meth_QListView_reset, METH_VARARGS, doc_QListView_reset},
    {sipName_resizeEvent, meth_QListView_resizeEvent, METH_VARARGS, doc_QListView_resizeEvent},
    {sipName_resizeMode, meth_QListView_resizeMode, METH_VARARGS, doc_QListView_resizeMode},
    {sipName_rowsAboutToBeRemoved, meth_QListView_rowsAboutToBeRemoved, METH_VARARGS, doc_QListView_rowsAboutToBeRemoved},
    {sipName_rowsInserted, meth_QListView_rowsInserted, METH_VARARGS, doc_QListView_rowsInserted},
    {sipName_scrollContentsBy, meth_QListView_scrollContentsBy, METH_VARARGS, doc_QListView_scrollContentsBy},
    {sipName_scrollTo, SIP_MLMETH_CAST(meth_QListView_scrollTo), METH_VARARGS|METH_KEYWORDS, doc_QListView_scrollTo},
    {sipName_selectedIndexes, meth_QListView_selectedIndexes, METH_VARARGS, doc_QListView_selectedIndexes},
    {sipName_selectionChanged, meth_QListView_selectionChanged, METH_VARARGS, doc_QListView_selectionChanged},
    {sipName_setBatchSize, meth_QListView_setBatchSize, METH_VARARGS, doc_QListView_setBatchSize},
    {sipName_setFlow, meth_QListView_setFlow, METH_VARARGS, doc_QListView_setFlow},
    {sipName_setGridSize, meth_QListView_setGridSize, METH_VARARGS, doc_QListView_setGridSize},
    {sipName_setItemAlignment, meth_QListView_setItemAlignment, METH_VARARGS, doc_QListView_setItemAlignment},
    {sipName_setLayoutMode, meth_QListView_setLayoutMode, METH_VARARGS, doc_QListView_setLayoutMode},
    {sipName_setModelColumn, meth_QListView_setModelColumn, METH_VARARGS, doc_QListView_setModelColumn},
    {sipName_setMovement, meth_QListView_setMovement, METH_VARARGS, doc_QListView_setMovement},
    {sipName_setPositionForIndex, meth_QListView_setPositionForIndex, METH_VARARGS, doc_QListView_setPositionForIndex},
    {sipName_setResizeMode, meth_QListView_setResizeMode, METH_VARARGS, doc_QListView_setResizeMode},
    {sipName_setRootIndex, meth_QListView_setRootIndex, METH_VARARGS, doc_QListView_setRootIndex},
    {sipName_setRowHidden, meth_QListView_setRowHidden, METH_VARARGS, doc_QListView_setRowHidden},
    {sipName_setSelection, meth_QListView_setSelection, METH_VARARGS, doc_QListView_setSelection},
    {sipName_setSelectionRectVisible, meth_QListView_setSelectionRectVisible, METH_VARARGS, doc_QListView_setSelectionRectVisible},
    {sipName_setSpacing, meth_QListView_setSpacing, METH_VARARGS, doc_QListView_setSpacing},
    {sipName_setUniformItemSizes, meth_QListView_setUniformItemSizes, METH_VARARGS, doc_QListView_setUniformItemSizes},
    {sipName_setViewMode, meth_QListView_setViewMode, METH_VARARGS, doc_QListView_setViewMode},
    {sipName_setWordWrap, meth_QListView_setWordWrap, METH_VARARGS, doc_QListView_setWordWrap},
    {sipName_setWrapping, meth_QListView_setWrapping, METH_VARARGS, doc_QListView_setWrapping},
    {sipName_spacing, meth_QListView_spacing, METH_VARARGS, doc_QListView_spacing},
    {sipName_startDrag, meth_QListView_startDrag, METH_VARARGS, doc_QListView_startDrag},
    {sipName_timerEvent, meth_QListView_timerEvent, METH_VARARGS, doc_QListView_timerEvent},
    {sipName_uniformItemSizes, meth_QListView_uniformItemSizes, METH_VARARGS, doc_QListView_uniformItemSizes},
    {sipName_updateGeometries, meth_QListView_updateGeometries, METH_VARARGS, doc_QListView_updateGeometries},
    {sipName_verticalOffset, meth_QListView_verticalOffset, METH_VARARGS, doc_QListView_verticalOffset},
    {sipName_viewMode, meth_QListView_viewMode, METH_VARARGS, doc_QListView_viewMode},
    {sipName_viewportSizeHint, meth_QListView_viewportSizeHint, METH_VARARGS, doc_QListView_viewportSizeHint},
    {sipName_visualRect, meth_QListView_visualRect, METH_VARARGS, doc_QListView_visualRect},
    {sipName_visualRegionForSelection, meth_QListView_visualRegionForSelection, METH_VARARGS, doc_QListView_visualRegionForSelection},
    {sipName_wheelEvent, meth_QListView_wheelEvent, METH_VARARGS, doc_QListView_wheelEvent},
    {sipName_wordWrap, meth_QListView_wordWrap, METH_VARARGS, doc_QListView_wordWrap}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QListView[] = {
    {sipName_LeftToRight, static_cast<int>(::QListView::LeftToRight)},
    {sipName_TopToBottom, static_cast<int>(::QListView::TopToBottom)},
    {sipName_SinglePass, static_cast<int>(::QListView::SinglePass)},
    {sipName_Batched, static_cast<int>(::QListView::Batched)},
    {sipName_Static, static_cast<int>(::QListView::Static)},
    {sipName_Free, static_cast<int>(::QListView::Free)},
    {sipName_Snap, static_cast<int>(::QListView::Snap)},
    {sipName_Fixed, static_cast<int>(::QListView::Fixed)},
    {sipName_Adjust, static_cast<int>(::QListView::Adjust)},
    {sipName_ListMode, static_cast<int>(::QListView::ListMode)},
    {sipName_IconMode, static_cast<int>(::QListView::IconMode)},
    {0, 0}
};

PyDoc_STRVAR(doc_QListView, "\1QListView(parent: QWidget|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QListView[] = {
    {"indexesMoved(QModelIndexList)", "\1indexesMoved(self, indexes: Iterable[QModelIndex])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QListView = {
    &::QListView::staticMetaObject,
    signals_QListView,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QListView = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QListView,
        SIP_NULLPTR,
        &plugin_QListView,
    },
    {
        sipNameNr_QListView,
        {0, 0, 1},
        65, methods_QListView,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QListView, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QListView,
    -1,
    -1,
    supers_QListView,
    SIP_NULLPTR,
    init_type_QListView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QListView,
    SIP_NULLPTR,
    array_QListView,
    SIP_NULLPTR,
    release_QListView,
    cast_QListView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QListView,
    sizeof (::QListView),
};
